
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';
import 'package:nan_common_utils/nan_base_dialog.dart';
import 'package:nan_common_utils/nan_util.dart';

class NanWidgetUtil{

  static Widget commonTextField(TextEditingController textEditingController,{int maxLines=1,bool isHiddenLine = false,bool isRequired=false,double rightIconWidth=30,int maxLength,double height,bool enabled=true,String leftTitle,String rightImg='location',String hintText="请输入",int flex=2,TextInputAction textInputAction=TextInputAction.done,List<TextInputFormatter> inputFormatters,TextInputType keyboardType,GestureTapCallback locationnTap,Function onChangeFun}){  
    return Column(
      children: [
        Container(
          color: Colors.white,
          height: height,
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Padding(
                padding: EdgeInsets.only(left: 13,right: 20),
                child: Row(
                  children: [
                    Offstage(
                      offstage: !isRequired,
                      child: Text("*",style: TextStyle(color: Colors.redAccent,fontSize: 18,fontWeight: FontWeight.bold),),
                    ),
                    Text(leftTitle,style: TextStyle(color: Colors.black,fontSize: 14),)
                  ],
                ),
              ),
              Expanded(
                flex: flex,
                child: Container(
                  child: TextField(
                    enabled: enabled,
                    maxLines: maxLines,//null,
                    maxLength: maxLength,//1024,
                    controller: textEditingController,
                    textAlign: TextAlign.right,
                    textInputAction: textInputAction,
                    inputFormatters: inputFormatters,
                    keyboardType: keyboardType,//TextInputType.number,
                    decoration: InputDecoration(
                      contentPadding: const EdgeInsets.all(10.0),
                      hintText: hintText,
                      hintStyle: TextStyle(color: Color.fromRGBO(204,204,204, 1)),
                      border: OutlineInputBorder(
                        borderSide: BorderSide.none
                      ),
                      filled: true,
                      fillColor: Colors.white//Colous.LoginTextBColor,
                    ),
                    onChanged: (value) {
                      // Toast.show(value, context,gravity: Toast.CENTER);
                      if (onChangeFun != null) {
                        onChangeFun(value);
                      }
                    },
                  ),
                ),
              ),
              Offstage(
                offstage: locationnTap == null,
                child: Padding(
                  padding: EdgeInsets.only(right: 10),
                  child: loadAssetImage(rightImg,width: rightIconWidth,height: rightIconWidth,onTap: locationnTap),
                ),
              )
            ],
          ),
        ),
        Offstage(
          offstage: isHiddenLine,
          child: Divider(height: 1,),
        )
      ],
    );           
  }

  static Widget reportRecordDetailWidget(leftTitle,{double mHeight=50,bool isRequired=false,double rightIconWidth=30,double rightIconHeight=30,double titleMarginLeft=13,Color leftTitleColor,Color bgColor=Colors.white,double fSize=14,String rightTitle,String rightIcon="scan",TextAlign textAlign =TextAlign.right,bool isHiddenRightIcon=true,GestureTapCallback rightIconOnTap,Color rightTitleColor,FontWeight fontWeight=FontWeight.normal}){
    Color leftTitleColors = (leftTitleColor == null?Color.fromRGBO(102,102,102, 1):leftTitleColor);
    return Container(
      color: bgColor,
      // padding: EdgeInsets.all(5),
      constraints: BoxConstraints(
        minHeight: mHeight
      ),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: <Widget>[
          Expanded(
            child: Padding(
                padding: EdgeInsets.only(left: 13,right: 20),
                child: Row(
                  children: [
                    Offstage(
                      offstage: !isRequired,
                      child: Text("*",style: TextStyle(color: Colors.redAccent,fontSize: 18,fontWeight: FontWeight.bold),),
                    ),
                    Text(leftTitle,style: TextStyle(fontSize: fSize,color: leftTitleColors,fontWeight: fontWeight))
                  ],
                ),
              ),
          ),
          rightIconOnTap == null?
          Offstage(
            offstage:  NanUtil.isStrEmpty(rightTitle) ? true:false,
            child: Container(
              constraints: BoxConstraints(
                maxWidth: NanUtil.kScreenWidth-100-20
              ),
              margin: EdgeInsets.only(right: 10),
              child: Text(NanUtil.isEmpty(rightTitle),style: TextStyle(color: rightTitleColor),textAlign: textAlign,),
            ),
          )
          :NanWidgetUtil.loadAssetImage(rightIcon,width: rightIconWidth,height: rightIconHeight,onTap: rightIconOnTap),
        ],
      ),
    );
  }

  //加载本地资源图片
  static Widget loadAssetImage(String name,{double width,double height,BoxFit fit,String format:'png',GestureTapCallback onTap}){
    return InkWell(
      child: Image.asset(
        NanUtil.getImagePath(name,format: format),
        height: height,
        width: width,
        fit: fit,
      ),
      onTap: onTap,
    );
  }

  // static void showUploadDialog(BuildContext context,{String upload,Color loadingColor,bool isDismiss=false,double radius=8,String tipMsg="提示文字",GestureTapCallback onTap}){
  //   showDialog(context: context,barrierDismissible: isDismiss,builder: (context) {
  //     return NanBaseDialog(
  //       Column(
  //         children: <Widget>[
  //           SizedBox(height: 20,),
  //           NanWidgetUtil.loadingWidget(loadingColor: loadingColor),
  //           InkWell(
  //             child: Padding(
  //               padding: EdgeInsets.only(top: 20),
  //               child: Text(tipMsg),
  //             ),
  //             onTap: onTap,
  //           )
  //         ],
  //       ), 
  //       150, 
  //       NanUtil.kScreenWidth - 46*2, 
  //       radius
  //     );
  //   },);
  // }

  static Widget loadingWidget({Color loadingColor}){
    loadingColor = loadingColor==null?Color.fromRGBO(0,189,144, 1):loadingColor;
    return SpinKitDoubleBounce(
      color: loadingColor,
    );
  }


}